==> openshift-model-tuned-5.12.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/TunedSpecBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TunedSpecBuilder extends io.fabric8.openshift.api.model.tuned.v1.TunedSpecFluentImpl<io.fabric8.openshift.api.model.tuned.v1.TunedSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.tuned.v1.TunedSpec,io.fabric8.openshift.api.model.tuned.v1.TunedSpecBuilder>{
  public TunedSpecBuilder() {
    this(false);
  }
  public TunedSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new TunedSpec(), validationEnabled);
  }
  public TunedSpecBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public TunedSpecBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TunedSpec(), validationEnabled);
  }
  public TunedSpecBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedSpecFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.TunedSpec instance) {
    this(fluent, instance, false);
  }
  public TunedSpecBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedSpecFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.TunedSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withRecommend(instance.getRecommend()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TunedSpecBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedSpec instance) {
    this(instance,false);
  }
  public TunedSpecBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withManagementState(instance.getManagementState()); 
    this.withProfile(instance.getProfile()); 
    this.withRecommend(instance.getRecommend()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.tuned.v1.TunedSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.tuned.v1.TunedSpec build() {
    TunedSpec buildable = new TunedSpec(fluent.getManagementState(),fluent.getProfile(),fluent.getRecommend());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TunedSpecBuilder that = (TunedSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-tuned-6.5.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/TunedSpecBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TunedSpecBuilder extends TunedSpecFluentImpl<TunedSpecBuilder> implements VisitableBuilder<TunedSpec,TunedSpecBuilder>{
  public TunedSpecBuilder() {
    this(false);
  }
  public TunedSpecBuilder(Boolean validationEnabled) {
    this(new TunedSpec(), validationEnabled);
  }
  public TunedSpecBuilder(TunedSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public TunedSpecBuilder(TunedSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TunedSpec(), validationEnabled);
  }
  public TunedSpecBuilder(TunedSpecFluent<?> fluent,TunedSpec instance) {
    this(fluent, instance, false);
  }
  public TunedSpecBuilder(TunedSpecFluent<?> fluent,TunedSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withRecommend(instance.getRecommend()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TunedSpecBuilder(TunedSpec instance) {
    this(instance,false);
  }
  public TunedSpecBuilder(TunedSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withManagementState(instance.getManagementState()); 
    this.withProfile(instance.getProfile()); 
    this.withRecommend(instance.getRecommend()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  TunedSpecFluent<?> fluent;
  Boolean validationEnabled;
  public TunedSpec build() {
    TunedSpec buildable = new TunedSpec(fluent.getManagementState(),fluent.getProfile(),fluent.getRecommend());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
